@@ -17,9 +17,7 @@
 #define QT_COMPILER_SUPPORTS_AVX512BW 1
 #define QT_COMPILER_SUPPORTS_AVX512CD 1
 #define QT_COMPILER_SUPPORTS_AVX512DQ 1
-#define QT_COMPILER_SUPPORTS_AVX512ER 1
 #define QT_COMPILER_SUPPORTS_AVX512IFMA 1
-#define QT_COMPILER_SUPPORTS_AVX512PF 1
 #define QT_COMPILER_SUPPORTS_AVX512VBMI 1
 #define QT_COMPILER_SUPPORTS_AVX512VL 1
 #define QT_FEATURE_debug_and_release -1
@@ -46,7 +44,7 @@
 #define QT_FEATURE_signaling_nan 1
 #define QT_FEATURE_static -1
 #define QT_COMPILER_SUPPORTS_SIMD_ALWAYS 1
-#define QT_VERSION_STR "5.15.10"
+#define QT_VERSION_STR "5.15.17"
 #define QT_VERSION_MAJOR 5
 #define QT_VERSION_MINOR 15
-#define QT_VERSION_PATCH 10
+#define QT_VERSION_PATCH 17
